<?php
/**
 * CT White Theme Customizer
 *
 * @package CT_White
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function gally_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'gally_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'gally_customize_partial_blogdescription',
			)
		);
	}
	
	$wp_customize->add_section(
		'gally_single_layout', array(
			'title'		=>	__('Single Post', 'gally'),
			'priority'	=>	50
		)
	);
	
	$wp_customize->add_setting(
		'gally_fimage_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_fimage_enable', array(
			'label'		=>	__('Show Featured Image', 'gally'),
			'type'		=>	'checkbox',
			'section'	=> 'gally_single_layout',
		)
	);
	
	$wp_customize->add_setting(
		'gally_single_date_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_single_date_enable', array(
			'label'		=>	__('Show Date', 'gally'),
			'type'		=>	'checkbox',
			'section'	=> 'gally_single_layout',
		)
	);
	
	$wp_customize->add_setting(
		'gally_single_author_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_single_author_enable', array(
			'label'		=>	__('Show Author', 'gally'),
			'type'		=>	'checkbox',
			'section'	=> 'gally_single_layout',
		)
	);
	
	$wp_customize->add_setting(
		'gally_single_cats_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_single_cats_enable', array(
			'label'		=>	__('Show Categories (Post Footer)', 'gally'),
			'type'		=>	'checkbox',
			'section'	=> 'gally_single_layout',
		)
	);
	
	$wp_customize->add_setting(
		'gally_single_tags_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_single_tags_enable', array(
			'label'		=>	__('Show Tags (Post Footer)', 'gally'),
			'type'		=>	'checkbox',
			'section'	=> 'gally_single_layout',
		)
	);
	
	$wp_customize->add_setting(
		'gally_single_nav_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_single_nav_enable', array(
			'label'		=>	__('Show Post Navigation', 'gally'),
			'type'		=>	'checkbox',
			'section'	=> 'gally_single_layout',
		)
	);
	
	$wp_customize->add_section('gally_social_section', array(
			'title' 	=> esc_html__('Social Icons','gally'),
			'priority' 	=> 70
	));
	
	$wp_customize->add_setting(
		'gally_social_enable', array(
			'default'	=>	1,
			'sanitize_callback'	=>	'gally_sanitize_checkbox'
		)
	);
	
	$wp_customize->add_control(
		'gally_social_enable', array(
			'label'	=>	__('Show Social Icons in Header', 'gally'),
			'type'	=>	'checkbox',
			'section'	=>	'gally_social_section',
			'priority'	=>	5
		)
	);

	$social_networks = array( //Redefinied in Sanitization Function.
					'none' 		=> esc_html__('-','gally'),
					'facebook-alt' 	=> esc_html__('Facebook', 'gally'),
					'twitter' 	=> esc_html__('Twitter', 'gally'),
					'instagram' => esc_html__('Instagram', 'gally'),
					'rss' 		=> esc_html__('RSS Feeds', 'gally'),
					'youtube' 	=> esc_html__('Youtube', 'gally'),
					'twitch' 	=> esc_html__('Twitch', 'gally'),
					'xing'		=> esc_html__('Xing', 'gally')
				);


    $social_count = count($social_networks);

	for ($s = 1 ; $s <= ($social_count - 3) ; $s++) :

		$wp_customize->add_setting(
			'gally_social_' . $s, array(
				'sanitize_callback' => 'gally_sanitize_social',
				'default' 			=> 'none',
			));

		$wp_customize->add_control( 'gally_social_' . $s, array(
					'settings' 	=> 'gally_social_' . $s,
					'label' 	=> esc_html__('Icon ','gally') . $s,
					'section' 	=> 'gally_social_section',
					'type' 		=> 'select',
					'choices' 	=> $social_networks,
		));

		$wp_customize->add_setting(
			'gally_social_url'.$s, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'gally_social_url' . $s, array(
			'label' 		=> esc_html__('Icon ','gally') . $s . esc_html__(' Url','gally'),
					'settings' 		=> 'gally_social_url' . $s,
					'section' 		=> 'gally_social_section',
					'type' 			=> 'url',
					'choices' 		=> $social_networks,
		));

	endfor;
	
}
add_action( 'customize_register', 'gally_customize_register' );

require_once get_template_directory() . '/inc/customizer/layout.php';

/**
 *	Sanitization of Checkbox
 */
 function gally_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}

/**
 *	Snitization of Radio
 */
function gally_sanitize_radio( $input, $setting ) {

	// Ensure input is a slug
	$input = sanitize_key( $input );

	// Get list of choices from the control
	// associated with the setting
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it;
	// otherwise, return the default
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 *	Sanitization of Social Media Control
 */
function gally_sanitize_social( $input ) {
	$social_networks = array(
				'none' ,
				'facebook-alt',
				'twitter',
				'instagram',
				'rss',
				'youtube',
				'twitch',
				'xing'
			);
	if ( in_array($input, $social_networks) )
		return $input;
	else
		return '';
}

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function gally_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function gally_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function gally_customize_preview_js() {
	wp_enqueue_script( 'ct-white-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), GALLY_VERSION, true );
}
add_action( 'customize_preview_init', 'gally_customize_preview_js' );
