<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package CT_White
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function gally_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'gally_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function gally_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'gally_pingback_header' );

	
/**
 *	Post Excerpt
 */
 function gally_excerpt($post = NULL, $limit = 40) {
	 	 
	if (NULL == $post ) {
		global $post;
	}

	 $output	=	'';

	 if ( isset($post->ID) && has_excerpt($post->ID) ) {
		 $output = $post->post_excerpt;
	 }

	 elseif ( isset( $post->post_content ) ) {
		if ( strpos($post->post_content, '<!--more-->') ) {
			$output	=	get_the_content('');
		}
		else {
			$output	=	wp_trim_words( strip_shortcodes( $post->post_content ), $limit );
		}
	}
	return $output;
}

function gally_footer_sidebar() { ?>
	<div id="footer-sidebar" class="col-12">
		<div class="container">
			<div class="row">
				<?php for( $i = 1; $i <= 3; $i++ ) { ?>
					<div class="footer footer-<?php echo $i ?> col-md-4">
						<?php if ( !is_active_sidebar('footer-' . $i)) return;?>
						<?php dynamic_sidebar('footer-' . $i) ?>
					</div>
				<?php } ?>
			</div>
		</div>
	</div>
<?php
}


/**
 *	Sidebar Function
 */
function gally_has_sidebar( $template ) {

   global $post;

   switch( $template ) {
	   
	    case "blog":
	    	return is_home() && get_theme_mod('gally_blog_sidebar_enable', '') == "" ? false : true;
		break;
		case "search":
	   		return is_search() && get_theme_mod('gally_search_sidebar_enable', '') == "" ? false : true;
		break;
		case "archive":
	   		return is_archive() && get_theme_mod('gally_archive_sidebar_enable', '') == "" ? false : true;
		break;
	    default:
	    	return true;
	}
}
add_action('gally_has_sidebar', 'gally_get_sidebar', 10, 1);


/**
 *	Gally Layout
 */
function gally_get_layout( $layout = 'grid3' ) {
	
	get_template_part( 'template-parts/content', $layout );
	
}
add_action('gally_layout', 'gally_get_layout');

/**
 *	Check whether Layout is a grid layout
 */
function gally_is_grid( $layout = 'grid3' ) {
	
	return strpos( $layout, 'grid') !== false ? true : false;
	
}


/**
 *	Load More using Ajax
 */
function gally_load_more() {
	
	check_ajax_referer( 'gally_load_more_posts', 'security' );
	
	$paged = $_POST['page'];
	
	$args = array(
		'post_type'			=>	'post',
		'posts_per_page'	=>	6,
		'paged'				=>	$paged
	);
	
	$ajax_query = new WP_Query( $args );

	// The Loop
	if ( $ajax_query->have_posts() ) :
	while ( $ajax_query->have_posts() ) : $ajax_query->the_post();
	
		gally_get_layout( get_theme_mod('gally_blog_layout', 'grid3') );
		
	endwhile;
	endif;
	
	// Reset Post Data
	wp_reset_postdata();
	
	die();
}
add_action( 'wp_ajax_gally_load_more', 'gally_load_more' );
add_action( 'wp_ajax_nopriv_gally_load_more', 'gally_load_more' );


/**
 * Search Form Filter
 */
function gally_search_form( $form ) {
	
	$form = str_replace( 'Search …', ' ', $form );
	return $form;
}
add_filter('get_search_form', 'gally_search_form', 10, 1);